==> dokuwiki_0.0.20080505.orig.tar.gz: dokuwiki-2008-05-05/inc/lang/fr/lang.php <==
<?php
/**
 * french language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author Sébastien Bauer <sebastien.bauer@advalvas.be>
 * @author Antoine Fixary <antoine.fixary@freesbee.fr>
 * @author cumulus <pta-n56@myamail.com>
 * @author Gwenn Gueguen <contact@demisel.net>
 * @author Guy Brand <gb@isis.u-strasbg.fr>
 * @author Fabien Chabreuil <fabien@integralpersonality.com>
 * @author Stéphane Chamberland <stephane.chamberland@ec.gc.ca>
 * @author Delassaux Julien <julien@delassaux.fr>
 * @author Maurice A. LeBlanc <leblancma@cooptel.qc.ca>
 * @author gb@isis.u-strasbg.fr
 */
$lang['encoding']              = 'utf-8';
$lang['direction']             = 'ltr';
$lang['doublequoteopening']    = '“';
$lang['doublequoteclosing']    = '”';
$lang['singlequoteopening']    = '‘';
$lang['singlequoteclosing']    = '’';
$lang['apostrophe']            = '\'';
$lang['btn_edit']              = 'Éditer cette page';
$lang['btn_source']            = 'Afficher le texte source';
$lang['btn_show']              = 'Afficher la page';
$lang['btn_create']            = 'Créer cette page';
$lang['btn_search']            = 'Rechercher';
$lang['btn_save']              = 'Enregistrer';
$lang['btn_preview']           = 'Aperçu';
$lang['btn_top']               = 'Haut de page';
$lang['btn_newer']             = '<< plus récent';
$lang['btn_older']             = 'moins récent >>';
$lang['btn_revs']              = 'Anciennes révisions';
$lang['btn_recent']            = 'Derniers changements';
$lang['btn_upload']            = 'Envoyer';
$lang['btn_cancel']            = 'Annuler';
$lang['btn_index']             = 'Index';
$lang['btn_secedit']           = 'Éditer';
$lang['btn_login']             = 'Connexion';
$lang['btn_logout']            = 'Déconnexion';
$lang['btn_admin']             = 'Admin';
$lang['btn_update']            = 'Rafraîchir';
$lang['btn_delete']            = 'Effacer';
$lang['btn_back']              = 'Retour';
$lang['btn_backlink']          = 'Liens vers cette page';
$lang['btn_backtomedia']       = 'Retour à la sélection du fichier média';
$lang['btn_subscribe']         = 'S\'abonner à la page';
$lang['btn_unsubscribe']       = 'Se désabonner de la page';
$lang['btn_subscribens']       = 'S\'abonner à la catégorie';
$lang['btn_unsubscribens']     = 'Se désabonner de la catégorie';
$lang['btn_profile']           = 'Mettre à jour le profil';
$lang['btn_reset']             = 'Réinitialiser';
$lang['btn_resendpwd']         = 'Envoyer le mot de passe';
$lang['btn_draft']             = 'Éditer brouillon';
$lang['btn_recover']           = 'Récupérer brouillon';
$lang['btn_draftdel']          = 'Effacer brouillon';
$lang['loggedinas']            = 'Connecté en tant que ';
$lang['user']                  = 'Utilisateur';
$lang['pass']                  = 'Mot de passe';
$lang['newpass']               = 'Nouveau mot de passe';
$lang['oldpass']               = 'Mot de passe actuel';
$lang['passchk']               = 'Répéter nouveau mot de passe';
$lang['remember']              = 'Mémoriser';
$lang['fullname']              = 'Nom complet';
$lang['email']                 = 'Adresse de courriel';
$lang['register']              = 'S\'enregistrer';
$lang['profile']               = 'Profil utilisateur';
$lang['badlogin']              = 'L\'utilisateur ou le mot de passe est incorrect.';
$lang['minoredit']             = 'Mineur';
$lang['draftdate']             = 'Brouillon auto-enregistré le';
$lang['regmissing']            = 'Désolé, vous devez remplir tous les champs.';
$lang['reguexists']            = 'Désolé, ce nom d\'utilisateur appartient déjà à un autre utilisateur.';
$lang['regsuccess']            = 'L\'utilisateur a été créé. Le mot de passe a été expédié par courriel.';
$lang['regsuccess2']           = 'L\'utilisateur a été créé.';
$lang['regmailfail']           = 'Il semble y avoir un problème à l\'envoi du courriel. Contactez l\'administrateur.';
$lang['regbadmail']            = 'L\'adresse de courriel semble incorrecte - si vous pensez que c\'est une erreur, contactez l\'administrateur.';
$lang['regbadpass']            = 'Les deux mots de passe fournis sont différents, recommencez SVP.';
$lang['regpwmail']             = 'Votre mot de passe DokuWiki';
$lang['reghere']               = 'Vous n\'avez pas encore de compte ? Enregistrez-vous ici ';
$lang['profna']                = 'Ce wiki ne permet pas de modifier les profils';
$lang['profnochange']          = 'Pas de changement, rien à faire.';
$lang['profnoempty']           = 'Un nom ou une adresse de courriel vide n\'est pas permis.';
$lang['profchanged']           = 'Mise à jour du profil réussie.';
$lang['pwdforget']             = 'Mot de passe oublié ? Faites-vous envoyer votre mot de passe ';
$lang['resendna']              = 'Ce wiki ne permet pas le renvoi de mot de passe.';
$lang['resendpwd']             = 'Renvoyer le mot de passe de';
$lang['resendpwdmissing']      = 'Désolé, vous devez remplir tous les champs.';
$lang['resendpwdnouser']       = 'Désolé, cet utilisateur est introuvable dans notre base.';
$lang['resendpwdbadauth']      = 'Désolé, ce code d\'authentification est invalide. Assurez vous d\'avoir utilisé le lien de confirmation.';
$lang['resendpwdconfirm']      = 'Un lien de confirmation vous a été envoyé par courriel.';
$lang['resendpwdsuccess']      = 'Votre nouveau mot de passe vous a été expédié par courriel.';
$lang['txt_upload']            = 'Sélectionnez un fichier à envoyer ';
$lang['txt_filename']          = 'Donnez un "wikiname" (optionnel) ';
$lang['txt_overwrt']           = 'Écraser le fichier cible';
$lang['lockedby']              = 'Actuellement bloqué par';
$lang['lockexpire']            = 'Le blocage expire à';
$lang['willexpire']            = 'Votre blocage pour modifier cette page expire dans une minute.\nPour éviter les conflits, utiliser le bouton Aperçu pour réinitialiser le minuteur.';
$lang['notsavedyet']           = 'Les changements non enregistrés seront perdus.\nVoulez-vous vraiment continuer ?';
$lang['rssfailed']             = 'Une erreur s\'est produite en récupérant ce flux : ';
$lang['nothingfound']          = 'Pas de réponse.';
$lang['mediaselect']           = 'Sélection de fichier';
$lang['fileupload']            = 'Envoi de fichier';
$lang['uploadsucc']            = 'Envoi réussi';
$lang['uploadfail']            = 'L\'envoi n\'a pas réussi. Les permissions sont-elles correctes ?';
$lang['uploadwrong']           = 'Envoi refusé. Cette extension de fichier est interdite !';
$lang['uploadexist']           = 'Le fichier existe. Envoi avorté.';
$lang['uploadbadcontent']      = 'Le contenu envoyé ne correspond pas à l\'extension du fichier %s.';
$lang['uploadspam']            = 'L\'envoi a été bloqué par la liste noire antispam.';
$lang['uploadxss']             = 'L\'envoi a été bloqué car son contenu est peut-être malveillant.';
$lang['deletesucc']            = 'Le fichier "%s" a été effacé.';
$lang['deletefail']            = 'Le fichier "%s" n\'a pu être effacé - vérifier les permissions.';
$lang['mediainuse']            = 'Le fichier "%s" n\'a pas été effacé - il est en cours d\'utilisation.';
$lang['namespaces']            = 'Catégories';
$lang['mediafiles']            = 'Fichiers disponibles dans';
$lang['js']['keepopen']        = 'Gardez la fenêtre ouverte pendant la sélection';
$lang['js']['hidedetails']     = 'Masquer détails';
$lang['mediausage']            = 'Utilisez la syntaxe suivante pour faire référence à ce fichier :';
$lang['mediaview']             = 'Voir fichier original';
$lang['mediaroot']             = 'root';
$lang['mediaupload']           = 'Envoyer un fichier dans la catégorie courante ici. Pour créer des sous-catégories, préfixez le nom du fichier par le nom de la sous-catégorie séparée par un double point.';
$lang['mediaextchange']        = 'Extension du fichier changée de .%s en .%s !';
$lang['reference']             = 'Références pour';
$lang['ref_inuse']             = 'Le fichier ne peut être effacé car il est utilisé par les pages suivantes :';
$lang['ref_hidden']            = 'Des références existent dans des pages que vous n\'avez pas la permission de lire';
$lang['hits']                  = 'occurrences trouvées';
$lang['quickhits']             = 'Pages trouvées ';
$lang['toc']                   = 'Table des matières';
$lang['current']               = 'version actuelle';
$lang['yours']                 = 'Votre version';
$lang['diff']                  = 'Différences avec la version actuelle';
$lang['diff2']                 = 'Différences entre les versions sélectionnées';
$lang['line']                  = 'Ligne';
$lang['breadcrumb']            = 'Piste';
$lang['youarehere']            = 'Vous êtes ici';
$lang['lastmod']               = 'Dernière modification';
$lang['by']                    = 'par';
$lang['deleted']               = 'effacée';
$lang['created']               = 'créée';
$lang['restored']              = 'ancienne révision restaurée';
$lang['external_edit']         = 'édition externe';
$lang['summary']               = 'Résumé';
$lang['mail_newpage']          = 'page ajoutée :';
$lang['mail_changed']          = 'page changée :';
$lang['mail_new_user']         = 'nouvel utilisateur :';
$lang['mail_upload']           = 'fichier envoyé :';
$lang['nosmblinks']            = 'Les liens vers les partages Windows ne fonctionnent qu\'avec Microsoft Internet Explorer.\nVous pouvez toujours faire un copier/coller du lien.';
$lang['qb_alert']              = 'SVP, entrez le texte que vous souhaitez formater.\nIl sera ajouté à la fin du document.';
$lang['qb_bold']               = 'Gras';
$lang['qb_italic']             = 'Italique';
$lang['qb_underl']             = 'Souligné';
$lang['qb_code']               = 'Code';
$lang['qb_strike']             = 'Texte barré';
$lang['qb_h1']                 = 'En-tête 1';
$lang['qb_h2']                 = 'En-tête 2';
$lang['qb_h3']                 = 'En-tête 3';
$lang['qb_h4']                 = 'En-tête 4';
$lang['qb_h5']                 = 'En-tête 5';
$lang['qb_link']               = 'Lien interne';
$lang['qb_extlink']            = 'Lien externe';
$lang['qb_hr']                 = 'Ligne horizontale';
$lang['qb_ol']                 = 'Liste numérotée';
$lang['qb_ul']                 = 'Liste à puce';
$lang['qb_media']              = 'Ajouter des images et autres fichiers';
$lang['qb_sig']                = 'Insérer une signature';
$lang['qb_smileys']            = 'Émoticons';
$lang['qb_chars']              = 'Caractères spéciaux';
$lang['del_confirm']           = 'Effacer cette entrée ?';
$lang['admin_register']        = 'Ajouter un nouvel utilisateur';
$lang['metaedit']              = 'Éditer les metadonnées';
$lang['metasaveerr']           = 'Erreur à l\'écriture des metadonnées';
$lang['metasaveok']            = 'Metadonnées enregistrées';
$lang['img_backto']            = 'Retour à';
$lang['img_title']             = 'Titre';
$lang['img_caption']           = 'Légende';
$lang['img_date']              = 'Date';
$lang['img_fname']             = 'Nom de fichier';
$lang['img_fsize']             = 'Taille';
$lang['img_artist']            = 'Auteur';
$lang['img_copyr']             = 'Copyright';
$lang['img_format']            = 'Format';
$lang['img_camera']            = 'Appareil photo';
$lang['img_keywords']          = 'Mots clef';
$lang['subscribe_success']     = 'Ajout de %s à la liste d\'abonnés de %s';
$lang['subscribe_error']       = 'Erreur à l\'ajout de %s à la liste d\'abonnés de %s';
$lang['subscribe_noaddress']   = 'Aucune adresse associée à votre nom d\'utilisateur, impossible de vous ajouter à la liste d\'abonnés';
$lang['unsubscribe_success']   = 'Suppression de %s de la liste d\'abonnés de %s';
$lang['unsubscribe_error']     = 'Erreur à la suppression de %s de la liste d\'abonnés de %s';
$lang['authmodfailed']         = 'Mauvais paramétrage de l\'authentification. Merci d\'informer l\'administrateur du Wiki.';
$lang['authtempfail']          = 'L\'authentification est temporairement indisponible. Si cela perdure, merci d\'informer l\'administrateur du Wiki.';
$lang['i_chooselang']          = 'Choisissez votre langue';
$lang['i_installer']           = 'Installeur DokuWiki';
$lang['i_wikiname']            = 'Nom du Wiki';
$lang['i_enableacl']           = 'Activer les ACL (recommandé)';
$lang['i_superuser']           = 'Super-utilisateur';
$lang['i_problems']            = 'L\'installeur a détecté les problèmes indiqués ci-dessous. Vous ne pouvez poursuivre tant qu\'ils n\'auront pas été corrigés.';
$lang['i_modified']            = 'Pour des raisons de sécurité ce script ne fonctionne qu\'avec une installation neuve et non modifiée de DokuWiki. Vous devriez ré-extraire les fichiers depuis le paquet téléchargé ou consulter les <a href="http://wiki.splitbrain.org/wiki:install">instructions d\'installation de DokuWiki</a>';
$lang['i_funcna']              = 'La fonction PHP <code>%s</code> n\'est pas disponible. Peut-être que votre hébergeur l\'a désactivée ?';
$lang['i_phpver']              = 'Votre version de PHP (<code>%s</code>) est antérieure à la version requise (<code>%s</code>. Vous devez mettre à jour votre installation de PHP.';
$lang['i_permfail']            = '<code>%s</code> n\'est pas accessible en écriture pour DokuWiki. Vous devez corriger les permissions de ce répertoire !';
$lang['i_confexists']          = '<code>%s</code> existe déjà';
$lang['i_writeerr']            = 'Impossible de créer <code>%s</code>. Vous devez vérifier les permissions des répertoires/fichiers et créer le fichier manuellement.';
$lang['i_badhash']             = 'dokuwiki.php non reconnu ou modifié (hash=<code>%s</code>)';
$lang['i_badval']              = '<code>%s</code> - valeur illégale ou vide';
$lang['i_success']             = 'L\'installation s\'est terminée avec succès. Vous pouvez maintenant supprimer le fichier install.php. Continuer avec <a href="doku.php">votre nouveau DokuWiki</a>.';
$lang['i_failure']             = 'Des erreurs sont survenues lors de l\'écriture des fichiers de configuration. Il vous faudra les corriger manuellement avant de pouvoir utiliser <a href="doku.php">votre nouveau DokuWiki</a>.';
$lang['i_policy']              = 'Politique d\'ACL initiale';
$lang['i_pol0']                = 'Wiki ouvert (lecture, écriture, envoi de fichiers pour tout le monde)';
$lang['i_pol1']                = 'Wiki public (lecture pour tout le monde, écriture et envoi de fichiers pour les utilisateurs enregistrés)';
$lang['i_pol2']                = 'Wiki fermé (lecture, écriture, envoi de fichiers pour les utilisateurs enregistrés uniquement)';
$lang['i_retry']               = 'Réessayer';

==> dokuwiki_0.0.20090214b.orig.tar.gz: dokuwiki-2009-02-14/inc/lang/fr/lang.php <==
<?php
/**
 * french language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author Sébastien Bauer <sebastien.bauer@advalvas.be>
 * @author Antoine Fixary <antoine.fixary@freesbee.fr>
 * @author cumulus <pta-n56@myamail.com>
 * @author Gwenn Gueguen <contact@demisel.net>
 * @author Guy Brand <gb@isis.u-strasbg.fr>
 * @author Fabien Chabreuil <fabien@integralpersonality.com>
 * @author Stéphane Chamberland <stephane.chamberland@ec.gc.ca>
 * @author Delassaux Julien <julien@delassaux.fr>
 * @author Maurice A. LeBlanc <leblancma@cooptel.qc.ca>
 * @author gb@isis.u-strasbg.fr
 * @author stephane.gully@gmail.com
 * @author Guillaume Turri <guillaume.turri@gmail.com>
 */
$lang['encoding']              = 'utf-8';
$lang['direction']             = 'ltr';
$lang['doublequoteopening']    = '“';
$lang['doublequoteclosing']    = '”';
$lang['singlequoteopening']    = '‘';
$lang['singlequoteclosing']    = '’';
$lang['apostrophe']            = '\'';
$lang['btn_edit']              = 'Éditer cette page';
$lang['btn_source']            = 'Afficher le texte source';
$lang['btn_show']              = 'Afficher la page';
$lang['btn_create']            = 'Créer cette page';
$lang['btn_search']            = 'Rechercher';
$lang['btn_save']              = 'Enregistrer';
$lang['btn_preview']           = 'Aperçu';
$lang['btn_top']               = 'Haut de page';
$lang['btn_newer']             = '<< plus récent';
$lang['btn_older']             = 'moins récent >>';
$lang['btn_revs']              = 'Anciennes révisions';
$lang['btn_recent']            = 'Derniers changements';
$lang['btn_upload']            = 'Envoyer';
$lang['btn_cancel']            = 'Annuler';
$lang['btn_index']             = 'Index';
$lang['btn_secedit']           = 'Éditer';
$lang['btn_login']             = 'Connexion';
$lang['btn_logout']            = 'Déconnexion';
$lang['btn_admin']             = 'Admin';
$lang['btn_update']            = 'Rafraîchir';
$lang['btn_delete']            = 'Effacer';
$lang['btn_back']              = 'Retour';
$lang['btn_backlink']          = 'Liens vers cette page';
$lang['btn_backtomedia']       = 'Retour à la sélection du fichier média';
$lang['btn_subscribe']         = 'S\'abonner à la page';
$lang['btn_unsubscribe']       = 'Se désabonner de la page';
$lang['btn_subscribens']       = 'S\'abonner à la catégorie';
$lang['btn_unsubscribens']     = 'Se désabonner de la catégorie';
$lang['btn_profile']           = 'Mettre à jour le profil';
$lang['btn_reset']             = 'Réinitialiser';
$lang['btn_resendpwd']         = 'Envoyer le mot de passe';
$lang['btn_draft']             = 'Éditer brouillon';
$lang['btn_recover']           = 'Récupérer brouillon';
$lang['btn_draftdel']          = 'Effacer brouillon';
$lang['loggedinas']            = 'Connecté en tant que ';
$lang['user']                  = 'Utilisateur';
$lang['pass']                  = 'Mot de passe';
$lang['newpass']               = 'Nouveau mot de passe';
$lang['oldpass']               = 'Mot de passe actuel';
$lang['passchk']               = 'Répéter nouveau mot de passe';
$lang['remember']              = 'Mémoriser';
$lang['fullname']              = 'Nom';
$lang['email']                 = 'Adresse de courriel';
$lang['register']              = 'S\'enregistrer';
$lang['profile']               = 'Profil utilisateur';
$lang['badlogin']              = 'L\'utilisateur ou le mot de passe est incorrect.';
$lang['minoredit']             = 'Mineur';
$lang['draftdate']             = 'Brouillon auto-enregistré le';
$lang['nosecedit']             = 'La page a changé entre temps, les informations de la section sont obsolètes ; la page complète a été chargée à la place.';
$lang['regmissing']            = 'Désolé, vous devez remplir tous les champs.';
$lang['reguexists']            = 'Désolé, ce nom d\'utilisateur est déjà pris';
$lang['regsuccess']            = 'L\'utilisateur a été créé. Le mot de passe a été expédié par courriel.';
$lang['regsuccess2']           = 'L\'utilisateur a été créé.';
$lang['regmailfail']           = 'Il semble y avoir un problème à l\'envoi du courriel. Contactez l\'administrateur.';
$lang['regbadmail']            = 'L\'adresse de courriel semble incorrecte - si vous pensez que c\'est une erreur, contactez l\'administrateur.';
$lang['regbadpass']            = 'Les deux mots de passe fournis sont différents, recommencez SVP.';
$lang['regpwmail']             = 'Votre mot de passe DokuWiki';
$lang['reghere']               = 'Vous n\'avez pas encore de compte ? Enregistrez-vous ici ';
$lang['profna']                = 'Ce wiki ne permet pas de modifier les profils';
$lang['profnochange']          = 'Pas de changement, rien à faire.';
$lang['profnoempty']           = 'Un nom ou une adresse de courriel vide n\'est pas permis.';
$lang['profchanged']           = 'Mise à jour du profil réussie.';
$lang['pwdforget']             = 'Mot de passe oublié ? Faites-vous envoyer votre mot de passe ';
$lang['resendna']              = 'Ce wiki ne permet pas le renvoi de mot de passe.';
$lang['resendpwd']             = 'Renvoyer le mot de passe de';
$lang['resendpwdmissing']      = 'Désolé, vous devez remplir tous les champs.';
$lang['resendpwdnouser']       = 'Désolé, cet utilisateur est introuvable dans notre base.';
$lang['resendpwdbadauth']      = 'Désolé, ce code d\'authentification est invalide. Assurez vous d\'avoir utilisé le lien de confirmation.';
$lang['resendpwdconfirm']      = 'Un lien de confirmation vous a été envoyé par courriel.';
$lang['resendpwdsuccess']      = 'Votre nouveau mot de passe vous a été expédié par courriel.';
$lang['license']               = 'Sauf mention contraire, le contenu de ce wiki est placé sous la licence suivante:';
$lang['licenseok']             = 'Note : En éditant cette page vous acceptez que le contenu soit placé sous les termes de la licence suivante :';
$lang['txt_upload']            = 'Sélectionnez un fichier à envoyer ';
$lang['txt_filename']          = 'Donnez un "wikiname" (optionnel) ';
$lang['txt_overwrt']           = 'Écraser le fichier cible';
$lang['lockedby']              = 'Actuellement bloqué par';
$lang['lockexpire']            = 'Le blocage expire à';
$lang['willexpire']            = 'Votre blocage pour modifier cette page expire dans une minute.\nPour éviter les conflits, utiliser le bouton Aperçu pour réinitialiser le minuteur.';
$lang['notsavedyet']           = 'Les changements non enregistrés seront perdus.\nVoulez-vous vraiment continuer ?';
$lang['rssfailed']             = 'Une erreur s\'est produite en récupérant ce flux : ';
$lang['nothingfound']          = 'Pas de réponse.';
$lang['mediaselect']           = 'Sélection de fichier';
$lang['fileupload']            = 'Envoi de fichier';
$lang['uploadsucc']            = 'Envoi réussi';
$lang['uploadfail']            = 'L\'envoi n\'a pas réussi. Les permissions sont-elles correctes ?';
$lang['uploadwrong']           = 'Envoi refusé. Cette extension de fichier est interdite !';
$lang['uploadexist']           = 'Le fichier existe. Envoi avorté.';
$lang['uploadbadcontent']      = 'Le contenu envoyé ne correspond pas à l\'extension du fichier %s.';
$lang['uploadspam']            = 'L\'envoi a été bloqué par la liste noire antispam.';
$lang['uploadxss']             = 'L\'envoi a été bloqué car son contenu est peut-être malveillant.';
$lang['uploadsize']            = 'Le fichier envoyé était trop gros. (max. %s)';
$lang['deletesucc']            = 'Le fichier "%s" a été effacé.';
$lang['deletefail']            = 'Le fichier "%s" n\'a pu être effacé - vérifier les permissions.';
$lang['mediainuse']            = 'Le fichier "%s" n\'a pas été effacé - il est en cours d\'utilisation.';
$lang['namespaces']            = 'Catégories';
$lang['mediafiles']            = 'Fichiers disponibles dans';
$lang['js']['keepopen']        = 'Gardez la fenêtre ouverte pendant la sélection';
$lang['js']['hidedetails']     = 'Masquer détails';
$lang['js']['nosmblinks']      = 'Les liens vers les partages Windows ne fonctionnent qu\'avec Microsoft Internet Explorer.
Vous pouvez toujours faire un copier/coller du lien.';
$lang['js']['mu_btn']          = 'Envoyer plusieurs fichiers en même temps';
$lang['mediausage']            = 'Utilisez la syntaxe suivante pour faire référence à ce fichier :';
$lang['mediaview']             = 'Voir fichier original';
$lang['mediaroot']             = 'root';
$lang['mediaupload']           = 'Envoyer un fichier dans la catégorie courante ici. Pour créer des sous-catégories, préfixez le nom du fichier par le nom de la sous-catégorie séparée par un double point.';
$lang['mediaextchange']        = 'Extension du fichier changée de .%s en .%s !';
$lang['reference']             = 'Références pour';
$lang['ref_inuse']             = 'Le fichier ne peut être effacé car il est utilisé par les pages suivantes :';
$lang['ref_hidden']            = 'Des références existent dans des pages que vous n\'avez pas la permission de lire';
$lang['hits']                  = 'occurrences trouvées';
$lang['quickhits']             = 'Pages trouvées ';
$lang['toc']                   = 'Table des matières';
$lang['current']               = 'version actuelle';
$lang['yours']                 = 'Votre version';
$lang['diff']                  = 'Différences avec la version actuelle';
$lang['diff2']                 = 'Différences entre les versions sélectionnées';
$lang['line']                  = 'Ligne';
$lang['breadcrumb']            = 'Piste';
$lang['youarehere']            = 'Vous êtes ici';
$lang['lastmod']               = 'Dernière modification';
$lang['by']                    = 'par';
$lang['deleted']               = 'effacée';
$lang['created']               = 'créée';
$lang['restored']              = 'ancienne révision restaurée';
$lang['external_edit']         = 'édition externe';
$lang['summary']               = 'Résumé';
$lang['noflash']               = 'L"extension <a href="http://www.adobe.com/products/flashplayer/">Adobe Flash Plugin</a> est nécessaire pour afficher ce contenu.';
$lang['mail_newpage']          = 'page ajoutée :';
$lang['mail_changed']          = 'page changée :';
$lang['mail_new_user']         = 'nouvel utilisateur :';
$lang['mail_upload']           = 'fichier envoyé :';
$lang['qb_alert']              = 'SVP, entrez le texte que vous souhaitez formater.\nIl sera ajouté à la fin du document.';
$lang['qb_bold']               = 'Gras';
$lang['qb_italic']             = 'Italique';
$lang['qb_underl']             = 'Souligné';
$lang['qb_code']               = 'Code';
$lang['qb_strike']             = 'Texte barré';
$lang['qb_h1']                 = 'En-tête 1';
$lang['qb_h2']                 = 'En-tête 2';
$lang['qb_h3']                 = 'En-tête 3';
$lang['qb_h4']                 = 'En-tête 4';
$lang['qb_h5']                 = 'En-tête 5';
$lang['qb_link']               = 'Lien interne';
$lang['qb_extlink']            = 'Lien externe';
$lang['qb_hr']                 = 'Ligne horizontale';
$lang['qb_ol']                 = 'Liste numérotée';
$lang['qb_ul']                 = 'Liste à puce';
$lang['qb_media']              = 'Ajouter des images et autres fichiers';
$lang['qb_sig']                = 'Insérer une signature';
$lang['qb_smileys']            = 'Émoticons';
$lang['qb_chars']              = 'Caractères spéciaux';
$lang['del_confirm']           = 'Effacer cette entrée ?';
$lang['admin_register']        = 'Ajouter un nouvel utilisateur';
$lang['metaedit']              = 'Éditer les metadonnées';
$lang['metasaveerr']           = 'Erreur à l\'écriture des metadonnées';
$lang['metasaveok']            = 'Metadonnées enregistrées';
$lang['img_backto']            = 'Retour à';
$lang['img_title']             = 'Titre';
$lang['img_caption']           = 'Légende';
$lang['img_date']              = 'Date';
$lang['img_fname']             = 'Nom de fichier';
$lang['img_fsize']             = 'Taille';
$lang['img_artist']            = 'Auteur';
$lang['img_copyr']             = 'Copyright';
$lang['img_format']            = 'Format';
$lang['img_camera']            = 'Appareil photo';
$lang['img_keywords']          = 'Mots clef';
$lang['subscribe_success']     = 'Ajout de %s à la liste d\'abonnés de %s';
$lang['subscribe_error']       = 'Erreur à l\'ajout de %s à la liste d\'abonnés de %s';
$lang['subscribe_noaddress']   = 'Aucune adresse associée à votre nom d\'utilisateur, impossible de vous ajouter à la liste d\'abonnés';
$lang['unsubscribe_success']   = 'Suppression de %s de la liste d\'abonnés de %s';
$lang['unsubscribe_error']     = 'Erreur à la suppression de %s de la liste d\'abonnés de %s';
$lang['authmodfailed']         = 'Mauvais paramétrage de l\'authentification. Merci d\'informer l\'administrateur du Wiki.';
$lang['authtempfail']          = 'L\'authentification est temporairement indisponible. Si cela perdure, merci d\'informer l\'administrateur du Wiki.';
$lang['i_chooselang']          = 'Choisissez votre langue';
$lang['i_installer']           = 'Installeur DokuWiki';
$lang['i_wikiname']            = 'Nom du Wiki';
$lang['i_enableacl']           = 'Activer les ACL (recommandé)';
$lang['i_superuser']           = 'Super-utilisateur';
$lang['i_problems']            = 'L\'installeur a détecté les problèmes indiqués ci-dessous. Vous ne pouvez poursuivre tant qu\'ils n\'auront pas été corrigés.';
$lang['i_modified']            = 'Pour des raisons de sécurité ce script ne fonctionne qu\'avec une installation neuve et non modifiée de DokuWiki. Vous devriez ré-extraire les fichiers depuis le paquet téléchargé ou consulter les <a href="http://dokuwiki.org/install">instructions d\'installation de DokuWiki</a>';
$lang['i_funcna']              = 'La fonction PHP <code>%s</code> n\'est pas disponible. Peut-être que votre hébergeur l\'a désactivée ?';
$lang['i_phpver']              = 'Votre version de PHP (<code>%s</code>) est antérieure à la version requise (<code>%s</code>. Vous devez mettre à jour votre installation de PHP.';
$lang['i_permfail']            = '<code>%s</code> n\'est pas accessible en écriture pour DokuWiki. Vous devez corriger les permissions de ce répertoire !';
$lang['i_confexists']          = '<code>%s</code> existe déjà';
$lang['i_writeerr']            = 'Impossible de créer <code>%s</code>. Vous devez vérifier les permissions des répertoires/fichiers et créer le fichier manuellement.';
$lang['i_badhash']             = 'dokuwiki.php non reconnu ou modifié (hash=<code>%s</code>)';
$lang['i_badval']              = '<code>%s</code> - valeur illégale ou vide';
$lang['i_success']             = 'L\'installation s\'est terminée avec succès. Vous pouvez maintenant supprimer le fichier install.php. Continuer avec <a href="doku.php">votre nouveau DokuWiki</a>.';
$lang['i_failure']             = 'Des erreurs sont survenues lors de l\'écriture des fichiers de configuration. Il vous faudra les corriger manuellement avant de pouvoir utiliser <a href="doku.php">votre nouveau DokuWiki</a>.';
$lang['i_policy']              = 'Politique d\'ACL initiale';
$lang['i_pol0']                = 'Wiki ouvert (lecture, écriture, envoi de fichiers pour tout le monde)';
$lang['i_pol1']                = 'Wiki public (lecture pour tout le monde, écriture et envoi de fichiers pour les utilisateurs enregistrés)';
$lang['i_pol2']                = 'Wiki fermé (lecture, écriture, envoi de fichiers pour les utilisateurs enregistrés uniquement)';
$lang['i_retry']               = 'Réessayer';
$lang['mu_intro']              = 'Ici vous pouvez envoyer plusieurs fichiers en même temps. Cliquez sur le bouton parcourir pour les ajouter. Cliquez sur envoyer lorsque c\'est prêt. ';
$lang['mu_gridname']           = 'Nom du fichier';
$lang['mu_gridsize']           = 'Taille';
$lang['mu_gridstat']           = 'État';
$lang['mu_namespace']          = 'Catégorie';
$lang['mu_browse']             = 'Parcourir';
$lang['mu_toobig']             = 'Trop gros';
$lang['mu_ready']              = 'Prêt à envoyer';
$lang['mu_done']               = 'Terminé';
$lang['mu_fail']               = 'Échoué';
$lang['mu_authfail']           = 'Session expirée';
$lang['mu_progress']           = '@PCT@% envoyé';
$lang['mu_filetypes']          = 'Types de fichiers acceptés';
$lang['recent_global']         = 'Vous êtes actuellement en train de regarder les modifications au sein du namespace <b>%s</b>. Vous pouvez aussi <a href="%s">voir les récentes modifications sur tout le wiki</a>';
